# aoc-reference-data

Reference data for Age of Empires II projects.

## Contents

- Events
- Players
- Teams
- RMS packs
- Platforms
- Datasets
- Constants

## Contributing

Most data changes rarely. However, the player data needs to be consistently updated. Assistance would be welcomed.

### Player Notability

Only notable players for games of the Age of Empires franchise may be added. Notability is defined as meeting at least one of the following criteria:

1. Has a page on the [Age of Empires Liquipedia](https://liquipedia.net/ageofempires/Main_Page).
1. Was ever a top 200 player listed on [Aoe Tournament Elo](https://aoe-elo.com/).
1. Was ever a top 250 player on the [primary competitive 1v1 ladder](https://www.ageofempires.com/stats/) for at least one month.
1. Is a [Twitch Partner](https://www.twitch.tv/p/partners/) and primarily streams a game of the Age of Empires franchise.

Other players may be added based on the maintainer's discretion for the benefit of the community at large.

### Team Notability

Only notable teams may be added. A team is notable if it has at least one player meeting any of the first three player notability requirements.

## Sources

Team data and some player social link data comes from [Liquipedia](https://liquipedia.net/ageofempires/Main_Page).
